@@ -55,6 +55,8 @@
 #include "historymenu.h"
 #include "mainmenu.h"
 #include "downloadsbutton.h"
+#include "tabmodel.h"
+#include "tabmrumodel.h"
 
 #include <algorithm>
 
@@ -121,6 +123,11 @@ BrowserWindow::SavedWindow::SavedWindow(BrowserWindow *window)
 
 bool BrowserWindow::SavedWindow::isValid() const
 {
+    for (const WebTab::SavedTab &tab : qAsConst(tabs)) {
+        if (!tab.isValid()) {
+            return false;
+        }
+    }
     return currentTab > -1;
 }
 
@@ -266,7 +273,9 @@ void BrowserWindow::postLaunch()
         break;
     }
 
-    show();
+    if (!mApp->isTestModeEnabled()) {
+        show();
+    }
 
     switch (m_windowType) {
     case Qz::BW_FirstAppWindow:
@@ -362,6 +371,10 @@ void BrowserWindow::setupUi()
     m_navigationToolbar = new NavigationBar(this);
     m_bookmarksToolbar = new BookmarksToolbar(this);
 
+    m_tabModel = new TabModel(this, this);
+    m_tabMruModel = new TabMruModel(this, this);
+    m_tabMruModel->setSourceModel(m_tabModel);
+
     m_navigationContainer = new NavigationContainer(this);
     m_navigationContainer->addWidget(m_navigationToolbar);
     m_navigationContainer->addWidget(m_bookmarksToolbar);
@@ -419,13 +432,6 @@ void BrowserWindow::setupUi()
 #endif
     }
 
-    // Workaround for Oxygen tooltips not having transparent background
-    QPalette pal = QToolTip::palette();
-    QColor col = pal.window().color();
-    col.setAlpha(0);
-    pal.setColor(QPalette::Window, col);
-    QToolTip::setPalette(pal);
-
     restoreUiState(uiState);
 
     // Set some sane minimum width
@@ -604,15 +610,17 @@ void BrowserWindow::loadSettings()
     }
     settings.endGroup();
 
+    m_statusBarVisible = showStatusBar;
     statusBar()->setVisible(!isFullScreen() && showStatusBar);
     m_bookmarksToolbar->setVisible(showBookmarksToolbar);
     m_navigationToolbar->setVisible(showNavigationToolbar);
 
 #ifndef Q_OS_MACOS
+    m_menuBarVisible = showMenuBar;
     menuBar()->setVisible(!isFullScreen() && showMenuBar);
 #endif
 
-    m_navigationToolbar->setSuperMenuVisible(!showMenuBar);
+    m_navigationToolbar->setSuperMenuVisible(isFullScreen() || !showMenuBar);
 }
 
 void BrowserWindow::goForward()
@@ -710,6 +718,16 @@ QAction* BrowserWindow::action(const QString &name) const
     return m_mainMenu->action(name);
 }
 
+TabModel *BrowserWindow::tabModel() const
+{
+    return m_tabModel;
+}
+
+TabMruModel *BrowserWindow::tabMruModel() const
+{
+    return m_tabMruModel;
+}
+
 void BrowserWindow::setWindowTitle(const QString &t)
 {
     QString title = t;
@@ -793,8 +811,8 @@ void BrowserWindow::loadAddress(const QUrl &url)
         int index = m_tabWidget->addView(url, qzSettings->newTabPosition);
         weView(index)->setFocus();
     } else {
-        weView()->load(url);
         weView()->setFocus();
+        weView()->load(url);
     }
 }
 
@@ -1018,7 +1036,9 @@ void BrowserWindow::restoreWindow(const SavedWindow &window)
 #ifdef QZ_WS_X11
     moveToVirtualDesktop(window.virtualDesktop);
 #endif
-    show(); // Window has to be visible before adding QWebEngineView's
+    if (!mApp->isTestModeEnabled()) {
+        show(); // Window has to be visible before adding QWebEngineView's
+    }
     m_tabWidget->restoreState(window.tabs, window.currentTab);
     updateStartupFocus();
 }
@@ -1128,7 +1148,12 @@ void BrowserWindow::webSearch()
 void BrowserWindow::searchOnPage()
 {
     if (weView() && weView()->webTab()) {
-        weView()->webTab()->showSearchToolBar();
+        const QString searchText = weView()->page()->selectedText();
+        if (!searchText.contains('\n')) {
+            weView()->webTab()->showSearchToolBar(searchText);
+        } else {
+            weView()->webTab()->showSearchToolBar();
+        }
     }
 }
 
@@ -1208,6 +1233,9 @@ bool BrowserWindow::event(QEvent *event)
 
             m_navigationContainer->hide();
             m_navigationToolbar->enterFullScreen();
+
+            // Show main menu button since menubar is hidden
+            m_navigationToolbar->setSuperMenuVisible(true);
         }
         else if (e->oldState() & Qt::WindowFullScreen && !(windowState() & Qt::WindowFullScreen)) {
             // Leave fullscreen
@@ -1319,15 +1347,13 @@ void BrowserWindow::keyPressEvent(QKeyEvent* event)
 
     case Qt::Key_Tab:
         if (event->modifiers() == Qt::ControlModifier) {
-            m_tabWidget->nextTab();
-            event->accept();
+            static_cast<QObject*>(m_tabWidget)->event(event);
         }
         break;
 
     case Qt::Key_Backtab:
         if (event->modifiers() == (Qt::ControlModifier + Qt::ShiftModifier)) {
-            m_tabWidget->previousTab();
-            event->accept();
+            static_cast<QObject*>(m_tabWidget)->event(event);
         }
         break;
 
@@ -1493,6 +1519,8 @@ void BrowserWindow::closeEvent(QCloseEvent* event)
         }
     }
 
+    emit aboutToClose();
+
     saveSettings();
     mApp->closedWindowsManager()->saveWindow(this);
 
