@@ -122,7 +122,6 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     // Set fallback icon theme (eg. on Windows/Mac)
     if (QIcon::fromTheme(QSL("view-refresh")).isNull()) {
-        QIcon::setThemeSearchPaths(QStringList() << QL1S(":/breeze-fallback"));
         QIcon::setThemeName(QSL("breeze-fallback"));
     }
 
@@ -307,7 +306,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     translateApp();
     loadSettings();
 
-    m_plugins = new PluginProxy;
+    m_plugins = new PluginProxy(this);
     m_autoFill = new AutoFill(this);
 
     if (!noAddons)
@@ -354,8 +353,9 @@ MainApplication::~MainApplication()
 
     // Delete all classes that are saving data in destructor
     delete m_bookmarks;
+    m_bookmarks = nullptr;
     delete m_cookieJar;
-    delete m_plugins;
+    m_cookieJar = nullptr;
 
     Settings::syncSettings();
 }
@@ -689,6 +689,10 @@ void MainApplication::quitApplication()
         return;
     }
 
+    for (BrowserWindow *window : qAsConst(m_windows)) {
+        emit window->aboutToClose();
+    }
+
     if (m_sessionManager && m_windows.count() > 0) {
         m_sessionManager->autoSaveLastSession();
     }
@@ -928,6 +932,9 @@ void MainApplication::loadSettings()
     webSettings->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
     webSettings->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    webSettings->setUnknownUrlSchemePolicy(QWebEngineSettings::AllowAllUnknownUrlSchemes);
+#endif
     webSettings->setDefaultTextEncoding(settings.value("DefaultEncoding", webSettings->defaultTextEncoding()).toString());
 
     setWheelScrollLines(settings.value("wheelScrollLines", wheelScrollLines()).toInt());
