@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - Qt web browser
-* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
+* Copyright (C) 2010-2018 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -32,8 +32,8 @@
 #include <QInputDialog>
 #include <QCloseEvent>
 
-CookieManager::CookieManager()
-    : QWidget()
+CookieManager::CookieManager(QWidget *parent)
+    : QDialog(parent)
     , ui(new Ui::CookieManager)
 {
     setAttribute(Qt::WA_DeleteOnClose);
@@ -75,8 +75,9 @@ CookieManager::CookieManager()
     ui->blackList->addItems(settings.value("blacklist", QStringList()).toStringList());
     settings.endGroup();
 
-    // QTWEBENGINE_DISABLED
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
     ui->filter3rdParty->hide();
+#endif
 
     ui->search->setPlaceholderText(tr("Search"));
     ui->cookieTree->setDefaultItemShowMode(TreeWidget::ItemsCollapsed);
