@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - Qt web browser
-* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
+* Copyright (C) 2010-2018 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,12 +17,12 @@
 * ============================================================ */
 #include "history.h"
 #include "historymodel.h"
-#include "tabbedwebview.h"
 #include "browserwindow.h"
 #include "iconprovider.h"
 #include "settings.h"
 #include "mainapplication.h"
 #include "sqldatabase.h"
+#include "webview.h"
 
 #include <QWebEngineProfile>
 
@@ -70,14 +70,11 @@ void History::addHistoryEntry(const QUrl &url, QString title)
         return;
     }
 
-    const QStringList ignoredSchemes = {
-        QStringLiteral("qupzilla"),
-        QStringLiteral("view-source"),
-        QStringLiteral("data"),
-        QStringLiteral("about")
+    const QStringList schemes = {
+        QSL("http"), QSL("https"), QSL("ftp"), QSL("file")
     };
 
-    if (url.isEmpty() || ignoredSchemes.contains(url.scheme())) {
+    if (!schemes.contains(url.scheme())) {
         return;
     }
 
@@ -149,6 +146,8 @@ void History::deleteHistoryEntry(const QList<int> &list)
     QSqlDatabase db = SqlDatabase::instance()->database();
     db.transaction();
 
+    QList<QUrl> urls;
+
     foreach (int index, list) {
         QSqlQuery query(SqlDatabase::instance()->database());
         query.prepare("SELECT count, date, url, title FROM history WHERE id=?");
@@ -175,9 +174,12 @@ void History::deleteHistoryEntry(const QList<int> &list)
         query.addBindValue(entry.url.toEncoded(QUrl::RemoveFragment));
         query.exec();
 
+        urls.append(entry.url);
         emit historyEntryDeleted(entry);
     }
 
+    mApp->webProfile()->clearVisitedLinks(urls);
+
     db.commit();
 }
 
