@@ -42,9 +42,9 @@
 #include <QContextMenuEvent>
 #include <QStyleOptionFrameV3>
 
-LocationBar::LocationBar(BrowserWindow* window)
-    : LineEdit(window)
-    , m_window(window)
+LocationBar::LocationBar(QWidget *parent)
+    : LineEdit(parent)
+    , m_window(nullptr)
     , m_webView(0)
     , m_holdingAlt(false)
     , m_oldTextLength(0)
@@ -55,12 +55,12 @@ LocationBar::LocationBar(BrowserWindow* window)
     setObjectName("locationbar");
     setDragEnabled(true);
 
-    // Disable Oxygen QLineEdit transitions, it breaks with setText() && home()
+    // Disable KDE QLineEdit transitions, it breaks with setText() && home()
     setProperty("_kde_no_animations", QVariant(true));
 
     m_bookmarkIcon = new BookmarksIcon(this);
     m_goIcon = new GoIcon(this);
-    m_siteIcon = new SiteIcon(m_window, this);
+    m_siteIcon = new SiteIcon(this);
     m_autofillIcon = new AutoFillIcon(this);
     DownIcon* down = new DownIcon(this);
 
@@ -71,7 +71,6 @@ LocationBar::LocationBar(BrowserWindow* window)
     addWidget(down, LineEdit::RightSide);
 
     m_completer = new LocationCompleter(this);
-    m_completer->setMainWindow(m_window);
     m_completer->setLocationBar(this);
     connect(m_completer, SIGNAL(showCompletion(QString,bool)), this, SLOT(showCompletion(QString,bool)));
     connect(m_completer, SIGNAL(showDomainCompletion(QString)), this, SLOT(showDomainCompletion(QString)));
@@ -112,6 +111,18 @@ LocationBar::LocationBar(BrowserWindow* window)
     QTimer::singleShot(0, this, SLOT(updatePlaceHolderText()));
 }
 
+BrowserWindow *LocationBar::browserWindow() const
+{
+    return m_window;
+}
+
+void LocationBar::setBrowserWindow(BrowserWindow *window)
+{
+    m_window = window;
+    m_completer->setMainWindow(m_window);
+    m_siteIcon->setBrowserWindow(m_window);
+}
+
 TabbedWebView* LocationBar::webView() const
 {
     return m_webView;
@@ -183,7 +194,8 @@ void LocationBar::showDomainCompletion(const QString &completion)
 QString LocationBar::convertUrlToText(const QUrl &url)
 {
     // It was most probably entered by user, so don't urlencode it
-    if (url.scheme().isEmpty()) {
+    // Also don't urlencode JavaScript code
+    if (url.scheme().isEmpty() || url.scheme() == QL1S("javascript")) {
         return QUrl::fromPercentEncoding(url.toEncoded());
     }
 
@@ -243,8 +255,11 @@ LocationBar::LoadAction LocationBar::loadAction(const QString &text)
     }
 
     if (!qzSettings->searchFromAddressBar) {
-        action.type = LoadAction::Url;
-        action.loadRequest = QUrl(t);
+        const QUrl &guessedUrl = QUrl::fromUserInput(t);
+        if (guessedUrl.isValid()) {
+            action.type = LoadAction::Url;
+            action.loadRequest = guessedUrl;
+        }
         return action;
     }
 
@@ -264,14 +279,16 @@ LocationBar::LoadAction LocationBar::loadAction(const QString &text)
     // Otherwise load as url
     const QUrl &guessedUrl = QUrl::fromUserInput(t);
     if (guessedUrl.isValid()) {
+        // Always allow javascript: to be loaded
+        const bool forceLoad = guessedUrl.scheme() == QL1S("javascript");
         // Only allow spaces in query
-        if (!QzTools::containsSpace(guessedUrl.toString(QUrl::RemoveQuery))) {
+        if (forceLoad || !QzTools::containsSpace(guessedUrl.toString(QUrl::RemoveQuery))) {
             // Only allow whitelisted schemes
-            const QSet<QString> whitelistedSchemes = {
+            static const QSet<QString> whitelistedSchemes = {
                 QSL("http"), QSL("https"), QSL("ftp"), QSL("file"),
                 QSL("data"), QSL("about"), QSL("qupzilla")
             };
-            if (whitelistedSchemes.contains(guessedUrl.scheme())) {
+            if (forceLoad || whitelistedSchemes.contains(guessedUrl.scheme())) {
                 action.type = LoadAction::Url;
                 action.loadRequest = guessedUrl;
                 return action;
@@ -388,6 +405,10 @@ void LocationBar::showUrl(const QUrl &url)
 
 void LocationBar::loadRequest(const LoadRequest &request)
 {
+    if (!m_webView->webTab()->isRestored()) {
+        return;
+    }
+
     const QString urlString = convertUrlToText(request.url());
 
     m_completer->closePopup();
@@ -465,7 +486,7 @@ void LocationBar::focusInEvent(QFocusEvent* event)
     clearTextFormat();
     LineEdit::focusInEvent(event);
 
-    if (Settings().value("Browser-View-Settings/instantBookmarksToolbar").toBool()) {
+    if (m_window && Settings().value("Browser-View-Settings/instantBookmarksToolbar").toBool()) {
         m_window->bookmarksToolbar()->show();
     }
 }
@@ -488,7 +509,7 @@ void LocationBar::focusOutEvent(QFocusEvent* event)
 
     refreshTextFormat();
 
-    if (Settings().value("Browser-View-Settings/instantBookmarksToolbar").toBool()) {
+    if (m_window && Settings().value("Browser-View-Settings/instantBookmarksToolbar").toBool()) {
         m_window->bookmarksToolbar()->hide();
     }
 }
@@ -499,9 +520,7 @@ void LocationBar::dropEvent(QDropEvent* event)
         const QUrl dropUrl = event->mimeData()->urls().at(0);
         if (WebView::isUrlValid(dropUrl)) {
             setText(dropUrl.toString());
-
-            m_webView->setFocus();
-            m_webView->userLoadAction(dropUrl);
+            loadRequest(dropUrl);
 
             QFocusEvent event(QFocusEvent::FocusOut);
             LineEdit::focusOutEvent(&event);
@@ -513,9 +532,7 @@ void LocationBar::dropEvent(QDropEvent* event)
         const QUrl dropUrl = QUrl(dropText);
         if (WebView::isUrlValid(dropUrl)) {
             setText(dropUrl.toString());
-
-            m_webView->setFocus();
-            m_webView->userLoadAction(dropUrl);
+            loadRequest(dropUrl);
 
             QFocusEvent event(QFocusEvent::FocusOut);
             LineEdit::focusOutEvent(&event);
@@ -571,7 +588,9 @@ void LocationBar::keyPressEvent(QKeyEvent* event)
 
         case Qt::AltModifier:
             m_completer->closePopup();
-            m_window->tabWidget()->addView(loadAction(text()).loadRequest);
+            if (m_window) {
+                m_window->tabWidget()->addView(loadAction(text()).loadRequest);
+            }
             m_holdingAlt = false;
             break;
 
