@@ -40,7 +40,7 @@ class QUPZILLA_EXPORT LocationBar : public LineEdit
     Q_OBJECT
 
 public:
-    explicit LocationBar(BrowserWindow* window);
+    explicit LocationBar(QWidget *parent = nullptr);
 
     struct LoadAction {
         enum Type {
@@ -55,6 +55,10 @@ public:
         LoadRequest loadRequest;
     };
 
+    // BrowserWindow can be null!
+    BrowserWindow *browserWindow() const;
+    void setBrowserWindow(BrowserWindow *window);
+
     TabbedWebView* webView() const;
     void setWebView(TabbedWebView* view);
 
