@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2015  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2018 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -34,8 +34,6 @@ public:
 
     void loadSettings();
 
-    QString userAgentForUrl(const QUrl &url) const;
-
     QString globalUserAgent() const;
     QString defaultUserAgent() const;
 
