@@ -527,10 +527,8 @@ void ComboTabBar::setUpLayout()
 {
     int height = qMax(m_mainTabBar->height(), m_pinnedTabBar->height());
 
-    // Workaround for Oxygen theme. For some reason, QTabBar::height() returns bigger
-    // height than it actually should.
-    if (mApp->styleName() == QLatin1String("oxygen")) {
-        height -= 4;
+    if (height < 1) {
+        height = qMax(m_mainTabBar->sizeHint().height(), m_pinnedTabBar->sizeHint().height());
     }
 
     // We need to setup heights even before m_mainTabBar->height() has correct value
@@ -538,7 +536,6 @@ void ComboTabBar::setUpLayout()
     height = qMax(5, height);
 
     setFixedHeight(height);
-    m_pinnedTabBar->setFixedHeight(height);
     m_leftContainer->setFixedHeight(height);
     m_rightContainer->setFixedHeight(height);
     m_mainTabBarWidget->setUpLayout();
@@ -546,10 +543,10 @@ void ComboTabBar::setUpLayout()
 
     setMinimumWidths();
 
-    if (isVisible() && m_mainTabBar->count() > 0) {
+    if (isVisible() && height > 5) {
         // ComboTabBar is now visible, we can sync heights of both tabbars
-        m_pinnedTabBar->setFixedHeight(m_mainTabBar->sizeHint().height());
-        m_mainTabBar->setFixedHeight(m_mainTabBar->sizeHint().height());
+        m_mainTabBar->setFixedHeight(height);
+        m_pinnedTabBar->setFixedHeight(height);
     }
 }
 
@@ -757,7 +754,7 @@ QTabBar::ButtonPosition ComboTabBar::iconButtonPosition() const
 
 QTabBar::ButtonPosition ComboTabBar::closeButtonPosition() const
 {
-    return (QTabBar::ButtonPosition)style()->styleHint(QStyle::SH_TabBar_CloseButtonPosition, 0, this);
+    return (QTabBar::ButtonPosition)style()->styleHint(QStyle::SH_TabBar_CloseButtonPosition, 0, m_mainTabBar);
 }
 
 QSize ComboTabBar::iconButtonSize() const
@@ -1442,6 +1439,10 @@ void TabBarHelper::mouseMoveEvent(QMouseEvent *event)
 
     // Don't allow to move tabs outside of tabbar
     if (m_dragInProgress && m_movingTab) {
+        // FIXME: This doesn't work at all with RTL...
+        if (isRightToLeft()) {
+            return;
+        }
         QRect r = tabRect(m_pressedIndex);
         r.moveLeft(r.x() + (event->pos().x() - m_dragStartPosition.x()));
         bool sendEvent = false;
@@ -1809,6 +1810,15 @@ CloseButton::CloseButton(QWidget* parent)
     setObjectName("combotabbar_tabs_close_button");
     setFocusPolicy(Qt::NoFocus);
     setCursor(Qt::ArrowCursor);
+    resize(sizeHint());
+}
+
+QSize CloseButton::sizeHint() const
+{
+    ensurePolished();
+    int width = style()->pixelMetric(QStyle::PM_TabCloseIndicatorWidth, nullptr, this);
+    int height = style()->pixelMetric(QStyle::PM_TabCloseIndicatorHeight, nullptr, this);
+    return QSize(width, height);
 }
 
 void CloseButton::enterEvent(QEvent* event)
