@@ -21,12 +21,12 @@
 #include "webtab.h"
 #include "toolbutton.h"
 #include "settings.h"
-#include "tabbedwebview.h"
 #include "mainapplication.h"
 #include "pluginproxy.h"
 #include "iconprovider.h"
 #include "tabcontextmenu.h"
 #include "searchenginesmanager.h"
+#include "tabmrumodel.h"
 
 #include <QMimeData>
 #include <QMouseEvent>
@@ -51,7 +51,7 @@ class TabBarTabMetrics : public QWidget
     Q_PROPERTY(int pinnedWidth READ pinnedWidth WRITE setPinnedWidth)
 
 public:
-    void init(TabBar *t)
+    void init()
     {
         if (!m_metrics.isEmpty()) {
             return;
@@ -60,7 +60,7 @@ public:
         m_metrics[1] = 100;
         m_metrics[2] = 100;
         m_metrics[3] = 100;
-        m_metrics[4] = t->iconButtonSize().width() + t->style()->pixelMetric(QStyle::PM_TabBarTabHSpace, nullptr, t);
+        m_metrics[4] = -1; // Will be initialized from TabBar
     }
 
     int normalMaxWidth() const { return m_metrics.value(0); }
@@ -111,7 +111,7 @@ TabBar::TabBar(BrowserWindow* window, TabWidget* tabWidget)
     setCloseButtonsToolTip(BrowserWindow::tr("Close Tab"));
     connect(this, SIGNAL(overFlowChanged(bool)), this, SLOT(overflowChanged(bool)));
 
-    tabMetrics()->init(this);
+    tabMetrics()->init();
 
     if (mApp->isPrivate()) {
         QLabel* privateBrowsing = new QLabel(this);
@@ -292,7 +292,7 @@ int TabBar::comboTabBarPixelMetric(ComboTabBar::SizeType sizeType) const
 {
     switch (sizeType) {
     case ComboTabBar::PinnedTabWidth:
-        return tabMetrics()->pinnedWidth();
+        return tabMetrics()->pinnedWidth() > 0 ? tabMetrics()->pinnedWidth() : 32;
 
     case ComboTabBar::ActiveTabMinimumWidth:
         return tabMetrics()->activeMinWidth();
@@ -348,14 +348,12 @@ void TabBar::contextMenuEvent(QContextMenuEvent* event)
 
     int index = tabAt(event->pos());
 
-    TabContextMenu menu(index, Qt::Horizontal, m_window, m_tabWidget);
+    TabContextMenu menu(index, m_window);
 
     // Prevent choosing first option with double rightclick
     const QPoint pos = event->globalPos();
     QPoint p(pos.x(), pos.y() + 1);
     menu.exec(p);
-
-    m_window->action(QSL("Other/RestoreClosedTab"))->setEnabled(true);
 }
 
 void TabBar::hideCloseButton(int index)
@@ -426,11 +424,13 @@ void TabBar::currentTabChanged(int index)
     // Don't hide close buttons when dragging tabs
     if (m_dragStartPosition.isNull()) {
         showCloseButton(index);
-        hideCloseButton(m_tabWidget->lastTabIndex());
-
+        if (m_lastTab) {
+            hideCloseButton(m_lastTab->tabIndex());
+        }
         QTimer::singleShot(100, this, [this]() { ensureVisible(); });
     }
 
+    m_lastTab = webTab(index);
     m_tabWidget->currentTabChanged(index);
 }
 
@@ -455,6 +455,22 @@ void TabBar::tabInserted(int index)
 {
     Q_UNUSED(index)
 
+    // Initialize pinned tab metrics
+    if (tabMetrics()->pinnedWidth() == -1) {
+        QTimer::singleShot(0, this, [this]() {
+            if (tabMetrics()->pinnedWidth() != -1) {
+                return;
+            }
+            QWidget *w = tabButton(0, iconButtonPosition());
+            if (w && w->parentWidget()) {
+                const QRect wg = w->parentWidget()->geometry();
+                const QRect wr = QStyle::visualRect(layoutDirection(), wg, w->geometry());
+                tabMetrics()->setPinnedWidth(iconButtonSize().width() + wr.x() * 2);
+                setUpLayout();
+            }
+        });
+    }
+
     setVisible(!(count() <= 1 && m_hideTabBarWithOneTab));
 }
 
@@ -511,6 +527,10 @@ void TabBar::mouseMoveEvent(QMouseEvent* event)
         return;
     }
 
+    if (count() == 1 && mApp->windowCount() == 1) {
+        return;
+    }
+
     if (!m_dragStartPosition.isNull()) {
         int offset = 0;
         const int eventY = event->pos().y();
@@ -620,7 +640,7 @@ void TabBar::dragMoveEvent(QDragMoveEvent *event)
     const int index = tabAt(event->pos());
     const QMimeData* mime = event->mimeData();
 
-    if (index == -1 || (mime->hasFormat(MIMETYPE) && event->source() == this)) {
+    if (index == -1) {
         ComboTabBar::dragMoveEvent(event);
         return;
     }
@@ -658,10 +678,6 @@ void TabBar::dropEvent(QDropEvent* event)
 
     event->acceptProposedAction();
 
-    if (mime->hasFormat(MIMETYPE) && event->source() == this) {
-        return;
-    }
-
     TabBar *sourceTabBar = qobject_cast<TabBar*>(event->source());
 
     int index = tabAt(event->pos());
@@ -682,7 +698,7 @@ void TabBar::dropEvent(QDropEvent* event)
         }
     } else {
         LoadRequest req;
-        WebTab* tab = m_window->weView(index)->webTab();
+        WebTab* tab = m_tabWidget->webTab(index);
         TabDropAction action = tabDropAction(event->pos(), tabRect(index), !mime->hasFormat(MIMETYPE));
         if (mime->hasUrls()) {
             req = mime->urls().at(0);
@@ -690,8 +706,8 @@ void TabBar::dropEvent(QDropEvent* event)
             req = mApp->searchEnginesManager()->searchResult(mime->text());
         }
         if (action == SelectTab) {
-            if (tab->isRestored() && req.isValid()) {
-                tab->webView()->load(req);
+            if (req.isValid()) {
+                tab->load(req);
             }
         } else if (action == PrependTab || action == AppendTab) {
             const int newIndex = action == PrependTab ? index : index + 1;
@@ -700,9 +716,13 @@ void TabBar::dropEvent(QDropEvent* event)
             } else if (mime->hasFormat(MIMETYPE) && sourceTabBar) {
                 WebTab *tab = sourceTabBar->webTab();
                 if (tab) {
-                    sourceTabBar->m_tabWidget->detachTab(tab);
-                    tab->setPinned(index < pinnedTabsCount());
-                    m_tabWidget->insertView(newIndex, tab, Qz::NT_SelectedTab);
+                    if (sourceTabBar == this) {
+                        tab->moveTab(newIndex > tab->tabIndex() ? newIndex - 1 : newIndex);
+                    } else {
+                        sourceTabBar->m_tabWidget->detachTab(tab);
+                        tab->setPinned(index < pinnedTabsCount());
+                        m_tabWidget->insertView(newIndex, tab, Qz::NT_SelectedTab);
+                    }
                 }
             }
         }
