@@ -30,6 +30,7 @@
 #include "qzsettings.h"
 #include "qztools.h"
 #include "tabicon.h"
+#include "pluginproxy.h"
 
 #include <QFile>
 #include <QTimer>
@@ -81,13 +82,11 @@ void MenuTabs::mouseReleaseEvent(QMouseEvent* event)
     QMenu::mouseReleaseEvent(event);
 }
 
-TabWidget::TabWidget(BrowserWindow* window, QWidget* parent)
+TabWidget::TabWidget(BrowserWindow *window, QWidget *parent)
     : TabStackedWidget(parent)
     , m_window(window)
     , m_locationBars(new QStackedWidget)
     , m_closedTabsManager(new ClosedTabsManager)
-    , m_lastTabIndex(-1)
-    , m_lastBackgroundTabIndex(-1)
 {
     setObjectName(QSL("tabwidget"));
 
@@ -99,7 +98,7 @@ TabWidget::TabWidget(BrowserWindow* window, QWidget* parent)
     connect(this, &TabStackedWidget::pinStateChanged, this, &TabWidget::changed);
 
     connect(m_tabBar, SIGNAL(tabCloseRequested(int)), this, SLOT(requestCloseTab(int)));
-    connect(m_tabBar, SIGNAL(tabMoved(int,int)), this, SLOT(tabMoved(int,int)));
+    connect(m_tabBar, &TabBar::tabMoved, this, &TabWidget::tabWasMoved);
 
     connect(m_tabBar, SIGNAL(moveAddTabButton(int)), this, SLOT(moveAddTabButton(int)));
 
@@ -152,6 +151,11 @@ TabWidget::TabWidget(BrowserWindow* window, QWidget* parent)
     loadSettings();
 }
 
+BrowserWindow *TabWidget::browserWindow() const
+{
+    return m_window;
+}
+
 void TabWidget::loadSettings()
 {
     Settings settings;
@@ -171,17 +175,17 @@ void TabWidget::loadSettings()
     updateClosedTabsButton();
 }
 
-WebTab* TabWidget::weTab()
+WebTab* TabWidget::weTab() const
 {
     return weTab(currentIndex());
 }
 
-WebTab* TabWidget::weTab(int index)
+WebTab* TabWidget::weTab(int index) const
 {
     return qobject_cast<WebTab*>(widget(index));
 }
 
-TabIcon* TabWidget::tabIcon(int index)
+TabIcon* TabWidget::tabIcon(int index) const
 {
     return weTab(index)->tabIcon();
 }
@@ -196,6 +200,24 @@ void TabWidget::updateClosedTabsButton()
     m_buttonClosedTabs->setVisible(m_showClosedTabsButton && canRestoreTab());
 }
 
+void TabWidget::keyPressEvent(QKeyEvent *event)
+{
+    if (mApp->plugins()->processKeyPress(Qz::ON_TabWidget, this, event)) {
+        return;
+    }
+
+    TabStackedWidget::keyPressEvent(event);
+}
+
+void TabWidget::keyReleaseEvent(QKeyEvent *event)
+{
+    if (mApp->plugins()->processKeyRelease(Qz::ON_TabWidget, this, event)) {
+        return;
+    }
+
+    TabStackedWidget::keyReleaseEvent(event);
+}
+
 bool TabWidget::isCurrentTabFresh() const
 {
     return m_currentTabFresh;
@@ -299,7 +321,6 @@ int TabWidget::addView(const LoadRequest &req, const Qz::NewTabPositionFlags &op
 int TabWidget::addView(const LoadRequest &req, const QString &title, const Qz::NewTabPositionFlags &openFlags, bool selectLine, int position, bool pinned)
 {
     QUrl url = req.url();
-    m_lastTabIndex = currentIndex();
     m_currentTabFresh = false;
 
     if (url.isEmpty() && !(openFlags & Qz::NT_CleanTab)) {
@@ -315,8 +336,8 @@ int TabWidget::addView(const LoadRequest &req, const QString &title, const Qz::N
     if (openAfterActive && position == -1) {
         // If we are opening newBgTab from pinned tab, make sure it won't be
         // opened between other pinned tabs
-        if (openFlags & Qz::NT_NotSelectedTab && m_lastBackgroundTabIndex != -1) {
-            position = m_lastBackgroundTabIndex + 1;
+        if (openFlags & Qz::NT_NotSelectedTab && m_lastBackgroundTab) {
+            position = m_lastBackgroundTab->tabIndex() + 1;
         }
         else {
             position = qMax(currentIndex() + 1, m_tabBar->pinnedTabsCount());
@@ -337,9 +358,8 @@ int TabWidget::addView(const LoadRequest &req, const QString &title, const Qz::N
 
     if (openFlags & Qz::NT_SelectedTab) {
         setCurrentIndex(index);
-    }
-    else {
-        m_lastBackgroundTabIndex = index;
+    } else {
+        m_lastBackgroundTab = webTab;
     }
 
     connect(webTab->webView(), SIGNAL(wantsCloseTab(int)), this, SLOT(closeTab(int)));
@@ -369,6 +389,8 @@ int TabWidget::addView(const LoadRequest &req, const QString &title, const Qz::N
     }
 
     emit changed();
+    emit tabInserted(index);
+
     return index;
 }
 
@@ -386,7 +408,7 @@ int TabWidget::insertView(int index, WebTab *tab, const Qz::NewTabPositionFlags
     if (openFlags.testFlag(Qz::NT_SelectedTab)) {
         setCurrentIndex(newIndex);
     } else {
-        m_lastBackgroundTabIndex = index;
+        m_lastBackgroundTab = tab;
     }
 
     connect(tab->webView(), SIGNAL(wantsCloseTab(int)), this, SLOT(closeTab(int)));
@@ -399,6 +421,8 @@ int TabWidget::insertView(int index, WebTab *tab, const Qz::NewTabPositionFlags
     }
 
     emit changed();
+    emit tabInserted(newIndex);
+
     return newIndex;
 }
 
@@ -435,14 +459,15 @@ void TabWidget::closeTab(int index)
     disconnect(webView, SIGNAL(urlChanged(QUrl)), this, SIGNAL(changed()));
     disconnect(webView, SIGNAL(ipChanged(QString)), m_window->ipLabel(), SLOT(setText(QString)));
 
-    m_lastBackgroundTabIndex = -1;
+    m_lastBackgroundTab = nullptr;
 
-    removeTab(index);
+    webTab->detach();
     webTab->deleteLater();
 
     updateClosedTabsButton();
 
     emit changed();
+    emit tabRemoved(index);
 }
 
 void TabWidget::requestCloseTab(int index)
@@ -460,10 +485,10 @@ void TabWidget::requestCloseTab(int index)
     if (count() <= 1) {
         // If we are not closing window upon closing last tab, let's just load new-tab-url
         if (m_dontCloseWithOneTab) {
-            if (webView->url() == m_urlOnNewTab) {
-                // We don't want to accumulate more than one closed tab, if user tries
-                // to close the last tab multiple times
-                m_closedTabsManager->takeLastClosedTab();
+            // We don't want to accumulate more than one closed tab, if user tries
+            // to close the last tab multiple times
+            if (webView->url() != m_urlOnNewTab) {
+                m_closedTabsManager->saveTab(webTab);
             }
             webView->zoomReset();
             webView->load(m_urlOnNewTab);
@@ -481,8 +506,7 @@ void TabWidget::currentTabChanged(int index)
     if (!validIndex(index))
         return;
 
-    m_lastBackgroundTabIndex = -1;
-    m_lastTabIndex = index;
+    m_lastBackgroundTab = nullptr;
     m_currentTabFresh = false;
 
     WebTab* webTab = weTab(index);
@@ -499,34 +523,27 @@ void TabWidget::currentTabChanged(int index)
     emit changed();
 }
 
-void TabWidget::tabMoved(int before, int after)
+void TabWidget::tabWasMoved(int before, int after)
 {
-    Q_UNUSED(before)
-    Q_UNUSED(after)
-
-    m_lastBackgroundTabIndex = -1;
-    m_lastTabIndex = before;
+    m_lastBackgroundTab = nullptr;
 
     emit changed();
+    emit tabMoved(before, after);
 }
 
 void TabWidget::setCurrentIndex(int index)
 {
-    m_lastTabIndex = currentIndex();
-
     TabStackedWidget::setCurrentIndex(index);
 }
 
 void TabWidget::nextTab()
 {
-    QKeyEvent fakeEvent(QKeyEvent::KeyPress, Qt::Key_Tab, Qt::ControlModifier);
-    keyPressEvent(&fakeEvent);
+    setCurrentIndex((currentIndex() + 1) % count());
 }
 
 void TabWidget::previousTab()
 {
-    QKeyEvent fakeEvent(QKeyEvent::KeyPress, Qt::Key_Backtab, QFlags<Qt::KeyboardModifier>(Qt::ControlModifier + Qt::ShiftModifier));
-    keyPressEvent(&fakeEvent);
+    setCurrentIndex(currentIndex() == 0 ? count() - 1 : currentIndex() - 1);
 }
 
 int TabWidget::normalTabsCount() const
@@ -548,9 +565,9 @@ void TabWidget::reloadTab(int index)
     weTab(index)->reload();
 }
 
-int TabWidget::lastTabIndex() const
+WebTab *TabWidget::webTab(int index) const
 {
-    return m_lastTabIndex;
+    return index < 0 ? weTab() : weTab(index);
 }
 
 int TabWidget::extraReservedWidth() const
@@ -632,16 +649,47 @@ void TabWidget::closeToLeft(int index)
     }
 }
 
+void TabWidget::moveTab(int from, int to)
+{
+    WebTab *tab = webTab(from);
+    if (!tab) {
+        return;
+    }
+    // (Un)pin tab when needed
+    if ((tab->isPinned() && to >= pinnedTabsCount()) || (!tab->isPinned() && to < pinnedTabsCount())) {
+        tab->togglePinned();
+    }
+    TabStackedWidget::moveTab(tab->tabIndex(), to);
+}
+
+int TabWidget::pinUnPinTab(int index, const QString &title)
+{
+    const int newIndex = TabStackedWidget::pinUnPinTab(index, title);
+    if (index != newIndex) {
+        emit tabMoved(index, newIndex);
+    }
+    return newIndex;
+}
+
 void TabWidget::detachTab(WebTab* tab)
 {
     Q_ASSERT(tab);
 
+    if (count() == 1 && mApp->windowCount() == 1) {
+        return;
+    }
+
     m_locationBars->removeWidget(tab->locationBar());
     disconnect(tab->webView(), SIGNAL(wantsCloseTab(int)), this, SLOT(closeTab(int)));
     disconnect(tab->webView(), SIGNAL(urlChanged(QUrl)), this, SIGNAL(changed()));
     disconnect(tab->webView(), SIGNAL(ipChanged(QString)), m_window->ipLabel(), SLOT(setText(QString)));
 
+    const int index = tab->tabIndex();
+
     tab->detach();
+    tab->setPinned(false);
+
+    emit tabRemoved(index);
 
     if (count() == 0) {
         m_window->close();
@@ -651,8 +699,13 @@ void TabWidget::detachTab(WebTab* tab)
 void TabWidget::detachTab(int index)
 {
     WebTab* tab = weTab(index);
+    Q_ASSERT(tab);
+
+    if (count() == 1 && mApp->windowCount() == 1) {
+        return;
+    }
+
     detachTab(tab);
-    tab->setPinned(false);
 
     BrowserWindow* window = mApp->createWindow(Qz::BW_NewWindow);
     window->setStartTab(tab);
@@ -672,6 +725,15 @@ int TabWidget::duplicateTab(int index)
     return id;
 }
 
+void TabWidget::loadTab(int index)
+{
+    if (!validIndex(index)) {
+        return;
+    }
+
+    weTab(index)->tabActivated();
+}
+
 void TabWidget::unloadTab(int index)
 {
     if (!validIndex(index)) {
@@ -775,10 +837,25 @@ bool TabWidget::restoreState(const QVector<WebTab::SavedTab> &tabs, int currentT
         return false;
     }
 
+    QVector<QPair<WebTab*, QVector<int>>> childTabs;
+
     for (int i = 0; i < tabs.size(); ++i) {
         WebTab::SavedTab tab = tabs.at(i);
-        int index = addView(QUrl(), Qz::NT_CleanSelectedTab, false, tab.isPinned);
-        weTab(index)->restoreTab(tab);
+        WebTab *webTab = weTab(addView(QUrl(), Qz::NT_CleanSelectedTab, false, tab.isPinned));
+        webTab->restoreTab(tab);
+        if (!tab.childTabs.isEmpty()) {
+            childTabs.append({webTab, tab.childTabs});
+        }
+    }
+
+    for (const auto p : qAsConst(childTabs)) {
+        const auto indices = p.second;
+        for (int index : indices) {
+            WebTab *t = weTab(index);
+            if (t) {
+                p.first->addChildTab(t);
+            }
+        }
     }
 
     setCurrentIndex(currentTab);
