@@ -18,8 +18,8 @@
 #ifndef TABWIDGET_H
 #define TABWIDGET_H
 
-#include <QTabWidget>
 #include <QMenu>
+#include <QPointer>
 
 #include "tabstackedwidget.h"
 #include "toolbutton.h"
@@ -66,9 +66,11 @@ class QUPZILLA_EXPORT TabWidget : public TabStackedWidget
 {
     Q_OBJECT
 public:
-    explicit TabWidget(BrowserWindow* mainclass, QWidget* parent = 0);
+    explicit TabWidget(BrowserWindow *window, QWidget *parent = nullptr);
     ~TabWidget();
 
+    BrowserWindow *browserWindow() const;
+
     bool restoreState(const QVector<WebTab::SavedTab> &tabs, int currentTab);
 
     void setCurrentIndex(int index);
@@ -79,9 +81,10 @@ public:
 
     int normalTabsCount() const;
     int pinnedTabsCount() const;
-    int lastTabIndex() const;
     int extraReservedWidth() const;
 
+    WebTab *webTab(int index = -1) const;
+
     TabBar* tabBar() const;
     ClosedTabsManager* closedTabsManager() const;
     QList<WebTab*> allTabs(bool withPinned = true);
@@ -93,6 +96,9 @@ public:
     ToolButton* buttonClosedTabs() const;
     AddTabButton* buttonAddTab() const;
 
+    void moveTab(int from, int to);
+    int pinUnPinTab(int index, const QString &title = QString());
+
     void detachTab(WebTab* tab);
 
 public slots:
@@ -116,6 +122,7 @@ public slots:
     void closeToRight(int index);
     void closeToLeft(int index);
     void detachTab(int index);
+    void loadTab(int index);
     void unloadTab(int index);
     void restoreClosedTab(QObject* obj = 0);
     void restoreAllClosedTabs();
@@ -127,6 +134,9 @@ public slots:
 
 signals:
     void changed();
+    void tabInserted(int index);
+    void tabRemoved(int index);
+    void tabMoved(int from, int to);
 
 private slots:
     void loadSettings();
@@ -135,16 +145,19 @@ private slots:
     void aboutToShowClosedTabsMenu();
 
     void actionChangeIndex();
-    void tabMoved(int before, int after);
+    void tabWasMoved(int before, int after);
 
 private:
-    WebTab* weTab();
-    WebTab* weTab(int index);
-    TabIcon* tabIcon(int index);
+    WebTab* weTab() const;
+    WebTab* weTab(int index) const;
+    TabIcon* tabIcon(int index) const;
 
     bool validIndex(int index) const;
     void updateClosedTabsButton();
 
+    void keyPressEvent(QKeyEvent *event) override;
+    void keyReleaseEvent(QKeyEvent *event) override;
+
     BrowserWindow* m_window;
     TabBar* m_tabBar;
     QStackedWidget* m_locationBars;
@@ -157,8 +170,7 @@ private:
     AddTabButton* m_buttonAddTab;
     AddTabButton* m_buttonAddTab2;
 
-    int m_lastTabIndex;
-    int m_lastBackgroundTabIndex;
+    QPointer<WebTab> m_lastBackgroundTab;
 
     bool m_dontCloseWithOneTab;
     bool m_showClosedTabsButton;
