@@ -25,7 +25,7 @@
 QString Scripts::setupWebChannel(quint32 worldId)
 {
     QString source =  QL1S("// ==UserScript==\n"
-                           "// %1\n"
+                           "%1\n"
                            "// ==/UserScript==\n\n"
                            "(function() {"
                            "%2"
@@ -72,9 +72,9 @@ QString Scripts::setupWebChannel(quint32 worldId)
 
     QString match;
     if (worldId == WebPage::SafeJsWorld) {
-        match = QSL("@exclude qupzilla:*");
+        match = QSL("// @exclude qupzilla:*\n// @exclude extension:*");
     } else {
-        match = QSL("@include qupzilla:*");
+        match = QSL("// @include qupzilla:*\n// @include extension:*");
     }
     return source.arg(match, QzTools::readAllFileContents(QSL(":/qtwebchannel/qwebchannel.js")));
 }
@@ -131,10 +131,10 @@ QString Scripts::setupFormObserver()
                           "    registerForm(document.forms[i]);"
                           ""
                           "var observer = new MutationObserver(function(mutations) {"
-                          "    for (var i = 0; i < mutations.length; ++i)"
-                          "        for (var j = 0; j < mutations[i].addedNodes.length; ++j)"
-                          "            if (mutations[i].addedNodes[j].tagName == 'FORM')"
-                          "                registerForm(mutations[i].addedNodes[j]);"
+                          "    for (var mutation of mutations)"
+                          "        for (var node of mutation.addedNodes)"
+                          "            if (node.tagName && node.tagName.toLowerCase() == 'form')"
+                          "                registerForm(node);"
                           "});"
                           "observer.observe(document.documentElement, { childList: true, subtree: true });"
                           ""
@@ -230,8 +230,10 @@ QString Scripts::completeFormData(const QByteArray &data)
                           "        var type = input.type.toLowerCase();"
                           "        if (type != 'text' && type != 'password' && type != 'email')"
                           "            continue;"
-                          "        if (input.name == key)"
+                          "        if (input.name == key) {"
                           "            input.value = val;"
+                          "            input.dispatchEvent(new Event('change'));"
+                          "        }"
                           "    }"
                           "}"
                           ""
@@ -303,11 +305,11 @@ QString Scripts::getFormData(const QPointF &pos)
 {
     QString source = QL1S("(function() {"
                           "var e = document.elementFromPoint(%1, %2);"
-                          "if (!e || e.tagName != 'INPUT')"
+                          "if (!e || e.tagName.toLowerCase() != 'input')"
                           "    return;"
                           "var fe = e.parentElement;"
                           "while (fe) {"
-                          "    if (fe.tagName == 'FORM')"
+                          "    if (fe.tagName.toLowerCase() == 'form')"
                           "        break;"
                           "    fe = fe.parentElement;"
                           "}"
