@@ -69,12 +69,10 @@ WebPage::WebPage(QObject* parent)
     : QWebEnginePage(mApp->webProfile(), parent)
     , m_fileWatcher(0)
     , m_runningLoop(0)
-    , m_loadProgress(-1)
+    , m_loadProgress(100)
     , m_blockAlerts(false)
     , m_secureStatus(false)
 {
-    setupWebChannelForUrl(QUrl());
-
     connect(this, &QWebEnginePage::loadProgress, this, &WebPage::progress);
     connect(this, &QWebEnginePage::loadFinished, this, &WebPage::finished);
     connect(this, &QWebEnginePage::urlChanged, this, &WebPage::urlChanged);
@@ -102,19 +100,25 @@ WebPage::WebPage(QObject* parent)
     });
 
     // Workaround for broken load started/finished signals in QtWebEngine 5.10
-    if (qstrcmp(qVersion(), "5.10.0") == 0) {
+    if (qstrncmp(qVersion(), "5.10.", 5) == 0) {
         connect(this, &QWebEnginePage::loadProgress, this, [this](int progress) {
             if (progress == 100) {
                 emit loadFinished(true);
             }
         });
     }
+
+    // Workaround for changing webchannel world inside acceptNavigationRequest not working
+    m_setupChannelTimer = new QTimer(this);
+    m_setupChannelTimer->setSingleShot(true);
+    m_setupChannelTimer->setInterval(100);
+    connect(m_setupChannelTimer, &QTimer::timeout, this, [this]() {
+        setupWebChannelForUrl(m_channelUrl);
+    });
 }
 
 WebPage::~WebPage()
 {
-    mApp->plugins()->emitWebPageDeleted(this);
-
     if (m_runningLoop) {
         m_runningLoop->exit(1);
         m_runningLoop = 0;
@@ -377,15 +381,24 @@ void WebPage::setupWebChannelForUrl(const QUrl &url)
         channel = new QWebChannel(this);
         ExternalJsObject::setupWebChannel(channel, this);
     }
-    if (url.scheme() == QL1S("qupzilla")) {
-        setWebChannel(channel, UnsafeJsWorld);
+    int worldId = -1;
+    if (url.scheme() == QL1S("qupzilla") || url.scheme() == QL1S("extension")) {
+        worldId = UnsafeJsWorld;
     } else {
-        setWebChannel(channel, SafeJsWorld);
+        worldId = SafeJsWorld;
+    }
+    if (worldId != m_channelWorldId) {
+        m_channelWorldId = worldId;
+        setWebChannel(channel, m_channelWorldId);
     }
 }
 
 bool WebPage::acceptNavigationRequest(const QUrl &url, QWebEnginePage::NavigationType type, bool isMainFrame)
 {
+    if (mApp->isClosing()) {
+        return QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
+    }
+
     if (!mApp->plugins()->acceptNavigationRequest(this, url, type, isMainFrame))
         return false;
 
@@ -407,8 +420,8 @@ bool WebPage::acceptNavigationRequest(const QUrl &url, QWebEnginePage::Navigatio
             const bool isWeb = url.scheme() == QL1S("http") || url.scheme() == QL1S("https") || url.scheme() == QL1S("file");
             const bool globalJsEnabled = mApp->webSettings()->testAttribute(QWebEngineSettings::JavascriptEnabled);
             settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, isWeb ? globalJsEnabled : true);
-
-            setupWebChannelForUrl(url);
+            m_channelUrl = url;
+            m_setupChannelTimer->start();
         }
         emit navigationRequestAccepted(url, type, isMainFrame);
     }
@@ -623,6 +636,9 @@ QWebEnginePage* WebPage::createWindow(QWebEnginePage::WebWindowType type)
         int index = window->tabWidget()->addView(QUrl(), pos);
         TabbedWebView* view = window->weView(index);
         view->setPage(new WebPage);
+        if (tView) {
+            tView->webTab()->addChildTab(view->webTab());
+        }
         // Workaround focus issue when creating tab
         if (pos.testFlag(Qz::NT_SelectedTab)) {
             QPointer<TabbedWebView> pview = view;
