@@ -49,6 +49,7 @@
 #include <QScrollBar>
 #include <QPrintDialog>
 #include <QPrinter>
+#include <QQuickWidget>
 
 bool WebView::s_forceContextMenuOnMouseRelease = false;
 
@@ -86,12 +87,17 @@ WebView::WebView(QWidget* parent)
                 return;
             }
             m_rwhvqt->installEventFilter(this);
+            if (QQuickWidget *w = qobject_cast<QQuickWidget*>(m_rwhvqt)) {
+                w->setClearColor(palette().color(QPalette::Window));
+            }
         });
     });
 }
 
 WebView::~WebView()
 {
+    mApp->plugins()->emitWebPageDeleted(m_page);
+
     WebInspector::unregisterView(this);
     WebScrollBarManager::instance()->removeWebView(this);
 }
@@ -121,8 +127,14 @@ QString WebView::title(bool allowEmpty) const
         return title;
     }
 
+    const QUrl u = url().isEmpty() ? m_page->requestedUrl() : url();
+
     if (title.isEmpty()) {
-        title = url().toString(QUrl::RemoveFragment);
+        title = u.host();
+    }
+
+    if (title.isEmpty()) {
+        title = u.toString(QUrl::RemoveFragment);
     }
 
     if (title.isEmpty() || title == QL1S("about:blank")) {
@@ -144,6 +156,11 @@ void WebView::setPage(WebPage *page)
     }
 
     if (m_page) {
+        if (m_page->isLoading()) {
+            emit m_page->loadProgress(100);
+            emit m_page->loadFinished(true);
+        }
+        mApp->plugins()->emitWebPageDeleted(m_page);
         m_page->setView(nullptr);
         m_page->deleteLater();
     }
@@ -152,6 +169,11 @@ void WebView::setPage(WebPage *page)
     m_page->setParent(this);
     QWebEngineView::setPage(m_page);
 
+    if (m_page->isLoading()) {
+        emit loadStarted();
+        emit loadProgress(m_page->m_loadProgress);
+    }
+
     connect(m_page, &WebPage::privacyChanged, this, &WebView::privacyChanged);
     connect(m_page, &WebPage::printRequested, this, &WebView::printPage);
 
@@ -271,7 +293,10 @@ bool WebView::forceContextMenuOnMouseRelease()
 // static
 void WebView::setForceContextMenuOnMouseRelease(bool force)
 {
+    // Windows open context menu on mouse release by default
+#ifndef Q_OS_WIN
     s_forceContextMenuOnMouseRelease = force;
+#endif
 }
 
 void WebView::addNotification(QWidget* notif)
@@ -377,14 +402,16 @@ void WebView::printPage()
 {
     Q_ASSERT(m_page);
 
-    QPrintDialog* dialog = new QPrintDialog(this);
+    QPrinter* printer = new QPrinter();
+    printer->setCreator(tr("QupZilla %1 (%2)").arg(Qz::VERSION, Qz::WWWADDRESS));
+    printer->setDocName(QzTools::filterCharsFromFilename(title()));
+
+    QPrintDialog* dialog = new QPrintDialog(printer, this);
     dialog->setOptions(QAbstractPrintDialog::PrintToFile | QAbstractPrintDialog::PrintShowPageSize);
 #ifndef Q_OS_WIN
     dialog->setOption(QAbstractPrintDialog::PrintPageRange);
     dialog->setOption(QAbstractPrintDialog::PrintCollateCopies);
 #endif
-    dialog->printer()->setCreator(tr("QupZilla %1 (%2)").arg(Qz::VERSION, Qz::WWWADDRESS));
-    dialog->printer()->setDocName(QzTools::getFileNameFromUrl(url()));
 
     if (dialog->exec() == QDialog::Accepted) {
         if (dialog->printer()->outputFormat() == QPrinter::PdfFormat) {
@@ -402,6 +429,10 @@ void WebView::printPage()
 void WebView::slotLoadStarted()
 {
     m_progress = 0;
+
+    if (title(/*allowEmpty*/true).isEmpty()) {
+        emit titleChanged(title());
+    }
 }
 
 void WebView::slotLoadProgress(int progress)
@@ -431,13 +462,12 @@ void WebView::slotIconChanged()
 
 void WebView::slotUrlChanged(const QUrl &url)
 {
-    Q_UNUSED(url)
-
-    // Don't save blank page / speed dial in tab history
-    if (!history()->canGoForward()  && history()->backItems(1).size() == 1) {
-        const QString s = LocationBar::convertUrlToText(history()->backItem().url());
-        if (s.isEmpty())
-            history()->clear();
+    if (!url.isEmpty() && title(/*allowEmpty*/true).isEmpty()) {
+        // Don't treat this as background activity change
+        const bool oldActivity = m_backgroundActivity;
+        m_backgroundActivity = true;
+        emit titleChanged(title());
+        m_backgroundActivity = oldActivity;
     }
 }
 
@@ -1238,6 +1268,17 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
     });
 }
 
+bool WebView::focusNextPrevChild(bool next)
+{
+    // QTBUG-67043
+    // Workaround QtWebEngine issue where QWebEngineView loses focus on second load() call.
+    if (next) {
+        setFocus();
+        return false;
+    }
+    return QWebEngineView::focusNextPrevChild(next);
+}
+
 void WebView::loadRequest(const LoadRequest &req)
 {
     QWebEngineView::load(req.webRequest());
