@@ -16,7 +16,7 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "searchtoolbar.h"
-#include "tabbedwebview.h"
+#include "webview.h"
 #include "webpage.h"
 #include "lineedit.h"
 #include "ui_searchtoolbar.h"
@@ -41,7 +41,7 @@ SearchToolBar::SearchToolBar(WebView* view, QWidget* parent)
     ui->previous->setShortcut(QKeySequence("Ctrl+Shift+G"));
 
     connect(ui->closeButton, SIGNAL(clicked()), this, SLOT(close()));
-    connect(ui->lineEdit, SIGNAL(textChanged(QString)), this, SLOT(findNext()));
+    connect(ui->lineEdit, SIGNAL(textEdited(QString)), this, SLOT(findNext()));
     connect(ui->lineEdit, SIGNAL(returnPressed()), this, SLOT(findNext()));
     connect(ui->next, SIGNAL(clicked()), this, SLOT(findNext()));
     connect(ui->previous, SIGNAL(clicked()), this, SLOT(findPrevious()));
@@ -113,6 +113,11 @@ void SearchToolBar::caseSensitivityChanged()
     searchText(ui->lineEdit->text());
 }
 
+void SearchToolBar::setText(const QString &text)
+{
+    ui->lineEdit->setText(text);
+}
+
 void SearchToolBar::searchText(const QString &text)
 {
     QPointer<SearchToolBar> guard = this;
