@@ -49,10 +49,9 @@ TabbedWebView::TabbedWebView(WebTab* webTab)
     connect(this, SIGNAL(urlChanged(QUrl)), this, SLOT(urlChanged(QUrl)));
 }
 
-void TabbedWebView::setWebPage(WebPage* page)
+void TabbedWebView::setPage(WebPage* page)
 {
-    page->setParent(this);
-    setPage(page);
+    WebView::setPage(page);
 
     connect(page, &WebPage::linkHovered, this, &TabbedWebView::linkHovered);
 }
@@ -166,8 +165,10 @@ void TabbedWebView::loadInNewTab(const LoadRequest &req, Qz::NewTabPositionFlags
 {
     if (m_window) {
         int index = m_window->tabWidget()->addView(QUrl(), position);
-        m_window->weView(index)->webTab()->locationBar()->showUrl(req.url());
-        m_window->weView(index)->load(req);
+        TabbedWebView *view = m_window->weView(index);
+        webTab()->addChildTab(view->webTab());
+        view->webTab()->locationBar()->showUrl(req.url());
+        view->load(req);
     }
 }
 
