@@ -36,11 +36,12 @@
 #include <QTimer>
 #include <QSplitter>
 
-static const int savedTabVersion = 3;
+static const int savedTabVersion = 6;
 
 WebTab::SavedTab::SavedTab()
     : isPinned(false)
     , zoomLevel(qzSettings->defaultZoomLevel)
+    , parentTab(-1)
 {
 }
 
@@ -52,6 +53,15 @@ WebTab::SavedTab::SavedTab(WebTab* webTab)
     history = webTab->historyData();
     isPinned = webTab->isPinned();
     zoomLevel = webTab->zoomLevel();
+    parentTab = webTab->parentTab() ? webTab->parentTab()->tabIndex() : -1;
+
+    const auto children = webTab->childTabs();
+    childTabs.reserve(children.count());
+    for (WebTab *child : children) {
+        childTabs.append(child->tabIndex());
+    }
+
+    sessionData = webTab->sessionData();
 }
 
 bool WebTab::SavedTab::isValid() const
@@ -67,6 +77,9 @@ void WebTab::SavedTab::clear()
     history.clear();
     isPinned = false;
     zoomLevel = qzSettings->defaultZoomLevel;
+    parentTab = -1;
+    childTabs.clear();
+    sessionData.clear();
 }
 
 QDataStream &operator <<(QDataStream &stream, const WebTab::SavedTab &tab)
@@ -78,6 +91,9 @@ QDataStream &operator <<(QDataStream &stream, const WebTab::SavedTab &tab)
     stream << tab.history;
     stream << tab.isPinned;
     stream << tab.zoomLevel;
+    stream << tab.parentTab;
+    stream << tab.childTabs;
+    stream << tab.sessionData;
 
     return stream;
 }
@@ -102,25 +118,31 @@ QDataStream &operator >>(QDataStream &stream, WebTab::SavedTab &tab)
     if (version >= 3)
         stream >> tab.zoomLevel;
 
+    if (version >= 4)
+        stream >> tab.parentTab;
+
+    if (version >= 5)
+        stream >> tab.childTabs;
+
+    if (version >= 6)
+        stream >> tab.sessionData;
+
     tab.icon = QIcon(pixmap);
 
     return stream;
 }
 
-WebTab::WebTab(BrowserWindow* window)
-    : QWidget()
-    , m_window(window)
-    , m_tabBar(0)
-    , m_isPinned(false)
+WebTab::WebTab(QWidget *parent)
+    : QWidget(parent)
 {
     setObjectName(QSL("webtab"));
 
     m_webView = new TabbedWebView(this);
-    m_webView->setBrowserWindow(m_window);
-    m_webView->setWebPage(new WebPage);
+    m_webView->setPage(new WebPage);
     m_webView->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
+    setFocusProxy(m_webView);
 
-    m_locationBar = new LocationBar(m_window);
+    m_locationBar = new LocationBar(this);
     m_locationBar->setWebView(m_webView);
 
     m_tabIcon = new TabIcon(this);
@@ -156,9 +178,20 @@ WebTab::WebTab(BrowserWindow* window)
     nlayout->setSpacing(1);
 
     connect(m_webView, SIGNAL(showNotification(QWidget*)), this, SLOT(showNotification(QWidget*)));
-    connect(m_webView, SIGNAL(loadStarted()), this, SLOT(loadStarted()));
     connect(m_webView, SIGNAL(loadFinished(bool)), this, SLOT(loadFinished()));
-    connect(m_webView, SIGNAL(titleChanged(QString)), this, SLOT(titleChanged(QString)));
+    connect(m_webView, &TabbedWebView::titleChanged, this, &WebTab::titleWasChanged);
+    connect(m_webView, &TabbedWebView::titleChanged, this, &WebTab::titleChanged);
+    connect(m_webView, &TabbedWebView::iconChanged, this, &WebTab::iconChanged);
+    connect(m_webView, &TabbedWebView::backgroundActivityChanged, this, &WebTab::backgroundActivityChanged);
+    connect(m_webView, &TabbedWebView::loadStarted, this, std::bind(&WebTab::loadingChanged, this, true));
+    connect(m_webView, &TabbedWebView::loadFinished, this, std::bind(&WebTab::loadingChanged, this, false));
+
+    auto pageChanged = [this](WebPage *page) {
+        connect(page, &WebPage::audioMutedChanged, this, &WebTab::playingChanged);
+        connect(page, &WebPage::recentlyAudibleChanged, this, &WebTab::mutedChanged);
+    };
+    pageChanged(m_webView->page());
+    connect(m_webView, &TabbedWebView::pageChanged, this, pageChanged);
 
     // Workaround QTabBar not immediately noticing resizing of tab buttons
     connect(m_tabIcon, &TabIcon::resized, this, [this]() {
@@ -168,6 +201,11 @@ WebTab::WebTab(BrowserWindow* window)
     });
 }
 
+BrowserWindow *WebTab::browserWindow() const
+{
+    return m_window;
+}
+
 TabbedWebView* WebTab::webView() const
 {
     return m_webView;
@@ -199,7 +237,7 @@ void WebTab::toggleWebInspector()
         delete m_splitter->widget(1);
 }
 
-void WebTab::showSearchToolBar()
+void WebTab::showSearchToolBar(const QString &searchText)
 {
     const int index = 1;
 
@@ -214,12 +252,18 @@ void WebTab::showSearchToolBar()
     }
 
     Q_ASSERT(toolBar);
+    if (!searchText.isEmpty()) {
+        toolBar->setText(searchText);
+    }
     toolBar->focusSearchLine();
 }
 
 QUrl WebTab::url() const
 {
     if (isRestored()) {
+        if (m_webView->url().isEmpty() && m_webView->isLoading()) {
+            return m_webView->page()->requestedUrl();
+        }
         return m_webView->url();
     }
     else {
@@ -270,21 +314,30 @@ void WebTab::detach()
     Q_ASSERT(m_window);
     Q_ASSERT(m_tabBar);
 
+    // Remove from tab tree
+    removeFromTabTree();
+
     // Remove icon from tab
     m_tabBar->setTabButton(tabIndex(), m_tabBar->iconButtonPosition(), nullptr);
     m_tabIcon->setParent(this);
 
     // Remove the tab from tabbar
     m_window->tabWidget()->removeTab(tabIndex());
-    setParent(0);
+    setParent(nullptr);
     // Remove the locationbar from window
     m_locationBar->setParent(this);
     // Detach TabbedWebView
-    m_webView->setBrowserWindow(0);
+    m_webView->setBrowserWindow(nullptr);
+
+    if (m_isCurrentTab) {
+        m_isCurrentTab = false;
+        emit currentTabChanged(m_isCurrentTab);
+    }
+    m_tabBar->disconnect(this);
 
     // WebTab is now standalone widget
-    m_window = 0;
-    m_tabBar = 0;
+    m_window = nullptr;
+    m_tabBar = nullptr;
 }
 
 void WebTab::attach(BrowserWindow* window)
@@ -293,9 +346,21 @@ void WebTab::attach(BrowserWindow* window)
     m_tabBar = m_window->tabWidget()->tabBar();
 
     m_webView->setBrowserWindow(m_window);
+    m_locationBar->setBrowserWindow(m_window);
     m_tabBar->setTabText(tabIndex(), title());
     m_tabBar->setTabButton(tabIndex(), m_tabBar->iconButtonPosition(), m_tabIcon);
     m_tabIcon->updateIcon();
+
+    auto currentChanged = [this](int index) {
+        const bool wasCurrent = m_isCurrentTab;
+        m_isCurrentTab = index == tabIndex();
+        if (wasCurrent != m_isCurrentTab) {
+            emit currentTabChanged(m_isCurrentTab);
+        }
+    };
+
+    currentChanged(m_tabBar->currentIndex());
+    connect(m_tabBar, &TabBar::currentChanged, this, currentChanged);
 }
 
 QByteArray WebTab::historyData() const
@@ -321,11 +386,22 @@ void WebTab::reload()
     m_webView->reload();
 }
 
+void WebTab::load(const LoadRequest &request)
+{
+    if (!isRestored()) {
+        tabActivated();
+        QTimer::singleShot(0, this, std::bind(&WebTab::load, this, request));
+    } else {
+        m_webView->load(request);
+    }
+}
+
 void WebTab::unload()
 {
     m_savedTab = SavedTab(this);
-    m_webView->history()->clear();
-    m_webView->setUrl(QUrl(QSL("about:blank")));
+    emit restoredChanged(isRestored());
+    m_webView->setPage(new WebPage);
+    m_webView->setFocus();
 }
 
 bool WebTab::isLoading() const
@@ -340,7 +416,16 @@ bool WebTab::isPinned() const
 
 void WebTab::setPinned(bool state)
 {
+    if (m_isPinned == state) {
+        return;
+    }
+
+    if (state) {
+        removeFromTabTree();
+    }
+
     m_isPinned = state;
+    emit pinnedChanged(m_isPinned);
 }
 
 bool WebTab::isMuted() const
@@ -348,6 +433,11 @@ bool WebTab::isMuted() const
     return m_webView->page()->isAudioMuted();
 }
 
+bool WebTab::isPlaying() const
+{
+    return m_webView->page()->recentlyAudible();
+}
+
 void WebTab::setMuted(bool muted)
 {
     m_webView->page()->setAudioMuted(muted);
@@ -359,6 +449,11 @@ void WebTab::toggleMuted()
     setMuted(!muted);
 }
 
+bool WebTab::backgroundActivity() const
+{
+    return m_webView->backgroundActivity();
+}
+
 LocationBar* WebTab::locationBar() const
 {
     return m_locationBar;
@@ -369,6 +464,85 @@ TabIcon* WebTab::tabIcon() const
     return m_tabIcon;
 }
 
+WebTab *WebTab::parentTab() const
+{
+    return m_parentTab;
+}
+
+void WebTab::setParentTab(WebTab *tab)
+{
+    if (m_isPinned || m_parentTab == tab) {
+        return;
+    }
+
+    if (tab && tab->isPinned()) {
+        return;
+    }
+
+    if (m_parentTab) {
+        const int index = m_parentTab->m_childTabs.indexOf(this);
+        if (index >= 0) {
+            m_parentTab->m_childTabs.removeAt(index);
+            emit m_parentTab->childTabRemoved(this, index);
+        }
+    }
+
+    m_parentTab = tab;
+
+    if (tab) {
+        m_parentTab = nullptr;
+        tab->addChildTab(this);
+    } else {
+        emit parentTabChanged(m_parentTab);
+    }
+}
+
+void WebTab::addChildTab(WebTab *tab, int index)
+{
+    if (m_isPinned || !tab || tab->isPinned()) {
+        return;
+    }
+
+    WebTab *oldParent = tab->m_parentTab;
+    tab->m_parentTab = this;
+    if (oldParent) {
+        const int index = oldParent->m_childTabs.indexOf(tab);
+        if (index >= 0) {
+            oldParent->m_childTabs.removeAt(index);
+            emit oldParent->childTabRemoved(tab, index);
+        }
+    }
+
+    if (index < 0 || index > m_childTabs.size()) {
+        index = 0;
+        if (addChildBehavior() == AppendChild) {
+            index = m_childTabs.size();
+        } else if (addChildBehavior() == PrependChild) {
+            index = 0;
+        }
+    }
+
+    m_childTabs.insert(index, tab);
+    emit childTabAdded(tab, index);
+
+    emit tab->parentTabChanged(this);
+}
+
+QVector<WebTab*> WebTab::childTabs() const
+{
+    return m_childTabs;
+}
+
+QHash<QString, QVariant> WebTab::sessionData() const
+{
+    return m_sessionData;
+}
+
+void WebTab::setSessionData(const QString &key, const QVariant &value)
+{
+    m_sessionData[key] = value;
+}
+
 bool WebTab::isRestored() const
 {
     return !m_savedTab.isValid();
@@ -378,10 +552,12 @@ void WebTab::restoreTab(const WebTab::SavedTab &tab)
 {
     Q_ASSERT(m_tabBar);
 
-    m_isPinned = tab.isPinned;
+    setPinned(tab.isPinned);
+    m_sessionData = tab.sessionData;
 
-    if (!m_isPinned && qzSettings->loadTabsOnActivation) {
+    if (!isPinned() && qzSettings->loadTabsOnActivation) {
         m_savedTab = tab;
+        emit restoredChanged(isRestored());
         int index = tabIndex();
 
         m_tabBar->setTabText(index, tab.title);
@@ -423,41 +599,26 @@ void WebTab::p_restoreTab(const WebTab::SavedTab &tab)
 
 void WebTab::showNotification(QWidget* notif)
 {
-    m_notificationWidget->setParent(nullptr);
     m_notificationWidget->setParent(this);
+    m_notificationWidget->raise();
     m_notificationWidget->setFixedWidth(width());
     m_notificationWidget->layout()->addWidget(notif);
     m_notificationWidget->show();
     notif->show();
 }
 
-void WebTab::loadStarted()
-{
-    if (!isRestored()) {
-        return;
-    }
-
-    if (m_tabBar && m_webView->title(/*allowEmpty*/true).isEmpty()) {
-        m_tabBar->setTabText(tabIndex(), tr("Loading..."));
-    }
-}
-
 void WebTab::loadFinished()
 {
-    if (isRestored()) {
-        titleChanged(m_webView->title());
-    } else if (m_webView->url().toString() == QL1S("about:blank")) {
-        m_webView->history()->clear();
-    }
+    titleWasChanged(m_webView->title());
 }
 
-void WebTab::titleChanged(const QString &title)
+void WebTab::titleWasChanged(const QString &title)
 {
-    if (!m_tabBar || !m_window || title.isEmpty() || !isRestored()) {
+    if (!m_tabBar || !m_window || title.isEmpty()) {
         return;
     }
 
-    if (isCurrentTab()) {
+    if (m_isCurrentTab) {
         m_window->setWindowTitle(tr("%1 - QupZilla").arg(title));
     }
 
@@ -476,9 +637,24 @@ void WebTab::tabActivated()
         }
         p_restoreTab(m_savedTab);
         m_savedTab.clear();
+        emit restoredChanged(isRestored());
     });
 }
 
+static WebTab::AddChildBehavior s_addChildBehavior = WebTab::AppendChild;
+
+// static
+WebTab::AddChildBehavior WebTab::addChildBehavior()
+{
+    return s_addChildBehavior;
+}
+
+// static
+void WebTab::setAddChildBehavior(AddChildBehavior behavior)
+{
+    s_addChildBehavior = behavior;
+}
+
 void WebTab::resizeEvent(QResizeEvent *event)
 {
     QWidget::resizeEvent(event);
@@ -486,16 +662,52 @@ void WebTab::resizeEvent(QResizeEvent *event)
     m_notificationWidget->setFixedWidth(width());
 }
 
+void WebTab::removeFromTabTree()
+{
+    WebTab *parentTab = m_parentTab;
+    const int parentIndex = parentTab ? parentTab->m_childTabs.indexOf(this) : -1;
+
+    setParentTab(nullptr);
+
+    int i = 0;
+    while (!m_childTabs.isEmpty()) {
+        WebTab *child = m_childTabs.at(0);
+        child->setParentTab(nullptr);
+        if (parentTab) {
+            parentTab->addChildTab(child, parentIndex + i++);
+        }
+    }
+}
+
 bool WebTab::isCurrentTab() const
 {
-    return m_tabBar && tabIndex() == m_tabBar->currentIndex();
+    return m_isCurrentTab;
+}
+
+void WebTab::makeCurrentTab()
+{
+    if (m_tabBar) {
+        m_tabBar->tabWidget()->setCurrentIndex(tabIndex());
+    }
+}
+
+void WebTab::closeTab()
+{
+    if (m_tabBar) {
+        m_tabBar->tabWidget()->closeTab(tabIndex());
+    }
+}
+
+void WebTab::moveTab(int to)
+{
+    if (m_tabBar) {
+        m_tabBar->tabWidget()->moveTab(tabIndex(), to);
+    }
 }
 
 int WebTab::tabIndex() const
 {
-    Q_ASSERT(m_tabBar);
-
-    return m_tabBar->tabWidget()->indexOf(const_cast<WebTab*>(this));
+    return m_tabBar ? m_tabBar->tabWidget()->indexOf(const_cast<WebTab*>(this)) : -1;
 }
 
 void WebTab::togglePinned()
@@ -503,7 +715,6 @@ void WebTab::togglePinned()
     Q_ASSERT(m_tabBar);
     Q_ASSERT(m_window);
 
-    m_isPinned = !m_isPinned;
-
+    setPinned(!isPinned());
     m_window->tabWidget()->pinUnPinTab(tabIndex(), title());
 }
