@@ -1,4 +1,12 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="sl_SI" version="2.1">
+<context>
+    <name>FCM_Button</name>
+    <message>
+        <location filename="../fcm_plugin.cpp" line="58"/>
+        <source>Flash Cookie Manager button</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>FCM_Dialog</name>
     <message>
@@ -250,22 +258,23 @@
 <context>
     <name>FCM_Plugin</name>
     <message>
-        <location filename="../fcm_plugin.cpp" line="129"/>
+        <location filename="../fcm_plugin.cpp" line="147"/>
+        <location filename="../fcm_plugin.cpp" line="377"/>
         <source>Flash Cookie Manager</source>
         <translation>Upravljalnik flash piškotkov</translation>
     </message>
     <message>
-        <location filename="../fcm_plugin.cpp" line="357"/>
+        <location filename="../fcm_plugin.cpp" line="378"/>
         <source>Show Flash Cookie Manager</source>
         <translation>Pokaži upravljalnik flash piškotkov</translation>
     </message>
     <message>
-        <location filename="../fcm_plugin.cpp" line="439"/>
+        <location filename="../fcm_plugin.cpp" line="459"/>
         <source>!default</source>
         <translation>!privzeto</translation>
     </message>
     <message>
-        <location filename="../fcm_plugin.cpp" line="451"/>
+        <location filename="../fcm_plugin.cpp" line="471"/>
         <source>!other</source>
         <translation>!ostalo</translation>
     </message>
