@@ -2,32 +2,32 @@
 <context>
     <name>SBI_ImagesIcon</name>
     <message>
-        <location filename="../sbi_imagesicon.cpp" line="33"/>
+        <location filename="../sbi_imagesicon.cpp" line="34"/>
         <source>Modify images loading settings per-site and globally</source>
         <translation>Pozměnit nastavení načítání obrázků podle stránky nebo globálně</translation>
     </message>
     <message>
-        <location filename="../sbi_imagesicon.cpp" line="57"/>
+        <location filename="../sbi_imagesicon.cpp" line="58"/>
         <source>Current Page Settings</source>
         <translation>Nastavení aktuální stránky</translation>
     </message>
     <message>
-        <location filename="../sbi_imagesicon.cpp" line="60"/>
+        <location filename="../sbi_imagesicon.cpp" line="61"/>
         <source>Disable loading images (temporarily)</source>
         <translation>Zakázat načítání obrázků (dočasně)</translation>
     </message>
     <message>
-        <location filename="../sbi_imagesicon.cpp" line="63"/>
+        <location filename="../sbi_imagesicon.cpp" line="64"/>
         <source>Enable loading images (temporarily)</source>
         <translation>Povolit načítání obrázků (dočasně)</translation>
     </message>
     <message>
-        <location filename="../sbi_imagesicon.cpp" line="67"/>
+        <location filename="../sbi_imagesicon.cpp" line="68"/>
         <source>Global Settings</source>
         <translation>Globální nastavení</translation>
     </message>
     <message>
-        <location filename="../sbi_imagesicon.cpp" line="69"/>
+        <location filename="../sbi_imagesicon.cpp" line="70"/>
         <source>Automatically load images</source>
         <translation>Automaticky načítat obrázky</translation>
     </message>
@@ -164,7 +164,7 @@
     <message>
         <location filename="../sbi_networkicondialog.cpp" line="70"/>
         <source>Are you sure you want to remove current proxy?</source>
-        <translation type="unfinished"/>
+        <translation>Opravdu chcete odstranit stávající proxy?</translation>
     </message>
 </context>
 <context>
@@ -207,7 +207,7 @@
     <message>
         <location filename="../sbi_proxywidget.ui" line="118"/>
         <source>&amp;Manual configuration</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Ruční nastavení</translation>
     </message>
 </context>
 <context>
