@@ -287,7 +287,11 @@ void TabManagerWidget::customContextMenuRequested(const QPoint &pos)
             // if items are not grouped by Window then actions "Close Other Tabs",
             // "Close Tabs To The Bottom" and "Close Tabs To The Top"
             // are ambiguous and should be hidden.
-            menu = new TabContextMenu(index, Qt::Vertical, mainWindow, mainWindow->tabWidget(), m_groupType == GroupByWindow);
+            TabContextMenu::Options options = TabContextMenu::VerticalTabs;
+            if (m_groupType == GroupByWindow) {
+                options |= TabContextMenu::ShowCloseOtherTabsActions;
+            }
+            menu = new TabContextMenu(index, mainWindow, options);
             menu->addSeparator();
         }
     }
@@ -788,11 +792,16 @@ void TabItem::setWebTab(WebTab* webTab)
     else
         setIsSavedTab(true);
 
-    connect(m_webTab->webView()->page(), SIGNAL(audioMutedChanged(bool)), this, SLOT(updateIcon()));
-    connect(m_webTab->webView()->page(), SIGNAL(loadFinished(bool)), this, SLOT(updateIcon()));
-    connect(m_webTab->webView()->page(), SIGNAL(loadStarted()), this, SLOT(updateIcon()));
     connect(m_webTab->webView(), SIGNAL(titleChanged(QString)), this, SLOT(setTitle(QString)));
     connect(m_webTab->webView(), SIGNAL(iconChanged(QIcon)), this, SLOT(updateIcon()));
+
+    auto pageChanged = [this](WebPage *page) {
+        connect(page, &WebPage::audioMutedChanged, this, &TabItem::updateIcon);
+        connect(page, &WebPage::loadFinished, this, &TabItem::updateIcon);
+        connect(page, &WebPage::loadStarted, this, &TabItem::updateIcon);
+    };
+    pageChanged(m_webTab->webView()->page());
+    connect(m_webTab->webView(), &WebView::pageChanged, this, pageChanged);
 }
 
 void TabItem::updateIcon()
